@@ -31,12 +31,17 @@ from .constants import (
     __version_info__,   # Python standard version definition
     )
 
+from .utils import (
+    logger,             # Python logger for PyCOM
+    )
+
 from .exceptions import (
     Error,                  # Base exception
     MethodNotFound,         # Remote method not found
     ServiceNotFound,        # Remote service not found
     RemoteError,            # Exception on remote side
     BadRequest,             # Client issued invalid request
+    AccessDenied,           # Access denied to this function
     ServiceNotAvailable,    # Remote service not available
     ConfigurationError,     # Error in configuration
     )
@@ -57,6 +62,7 @@ from .helpers import (
 
 from .zerojson import (
     RemoteComponent,    # Remote component implementation
+    create_task,        # Create repeatable task
     ioloop,             # IOLoop instance for a service
     )
 
@@ -69,3 +75,8 @@ from .nsclient import (
 from .launcher import (
     main,               # Main loop for a service
     )
+
+from .proxy import (
+    ProxyComponent,     # Proxying component
+    ProxyContext,       # Proxying context
+    )
