@@ -27,7 +27,7 @@
 """Demo service."""
 
 import pycom
-from pycom import constants
+
 
 INTERFACE = "org.pycom.demo"
 
@@ -45,4 +45,4 @@ class Demo(pycom.Service):
     def throw(self, request):  # pylint: disable-msg=W0613,R0201
         """This method throws exception with code ERROR_UNKNOWN."""
         raise pycom.RemoteError(repr(request.args),
-            code=constants.ERROR_UNKNOWN)
+            code=pycom.constants.ERROR_UNKNOWN)
