@@ -45,7 +45,7 @@ class Request(object):
     .. attribute:: session
 
        Session for current component - dict-like object of
-       type :class:`pycom.base.Session`
+       type :class:`pycom.base.BaseSession` (or subclass)
 
     .. attribute:: args
 
@@ -96,7 +96,11 @@ class Response(object):
 
 
 class BaseComponent(object):
-    """Abstract base class for components."""
+    """Abstract base class for components.
+
+    Any component can be used as a context manager.
+
+    """
 
     __slots__ = ()
 
@@ -129,6 +133,10 @@ class BaseComponent(object):
         """
         return self.invoke(constants.GENERIC_METHOD_INTROSPECT)
 
+    __enter__ = lambda self: self
+
+    __exit__ = lambda self, *args: self.close()
+
 
 #: Read-only dictionary with current configuration
 configuration = {}
@@ -166,9 +174,14 @@ class Session(dict):
 
     def __init__(self, session_id, *args, **kw):
         """Constructor."""
+        self._owner = kw.pop("session_factory", None)
         super(Session, self).__init__(*args, **kw)
         self.session_id = session_id
 
+    def discard(self):
+        """Discard this sessions and all it's data."""
+        if self._owner is not None:
+            self._owner.drop(self.session_id)
 
 # Private
 
