@@ -26,10 +26,11 @@
 
 """Common constants."""
 
+###BEGIN - here starts self-documenting part to include into Sphinx docs
+
 # Versions
 
-__version_info__ = (0, 4, 1)
-
+__version_info__ = (0, 4, 2)
 __version__ = "%d.%d.%d" % __version_info__
 
 # Error codes
@@ -38,6 +39,7 @@ ERROR_UNKNOWN = 1
 ERROR_METHOD_NOT_FOUND = 2
 ERROR_SERVICE_NOT_FOUND = 3
 ERROR_BAD_REQUEST = 4
+ERROR_ACCESS_DENIED = 5
 
 # Standard interfaces
 
@@ -51,8 +53,9 @@ PROTO_CMD_FINISH = b"FINISH"
 PROTO_STATUS_SUCCESS = b"OK"
 PROTO_STATUS_FAILURE = b"FAIL"
 PROTO_DEFAULT_TIMEOUT = 5000
+PROTO_SESSION_TIMEOUT = 3600 * 1000  # 1hr in ms
 
-GENERIC_METHOD_INTROSPECT = "__introspect__"
+GENERIC_METHOD_INTROSPECT = "introspect"
 
 # Nameserver constants
 
@@ -60,7 +63,10 @@ NS_METHOD_STAT = "stat"
 NS_METHOD_LOCATE = "locate"
 NS_METHOD_REGISTER = "register"
 NS_METHOD_LIST_SERVICES = "list_services"
+NS_SERVICE_TIMEOUT = 60000
 
 # Other constants
 
 NS_NAME_LOCAL = "local"
+
+###END - here ends self-documenting part to include into Sphinx docs
