@@ -177,13 +177,16 @@ class Method(object):
             return meth
 
         @pycom.interface("...")
-        class InterfaceWithMethods(object):
+        class InterfaceWithMethods(pycom.Service):
 
             @setup_my_hook
             @pycom.method("...")
             def method1(self, request):
                 pass  # ...
 
+       Do NOT try to use things like ``functools.wraps`` and
+       standard decorators on PyCOM methods, they behave in a different way.
+
     .. attribute:: required_arguments
     .. attribute:: optional_arguments
 
@@ -230,14 +233,17 @@ class Method(object):
         Returns :class:`pycom.Response` object.
 
         """
-        if (self.required_arguments or self.optional_arguments) \
-                and not isinstance(request.args, dict):
-            raise exceptions.BadRequest("Expected dictionary")
+        if self.required_arguments or self.optional_arguments:
+            if request.args is None:
+                request.args = {}
+            if not isinstance(request.args, dict):
+                raise exceptions.BadRequest("Expected dictionary as argument "
+                    "for %s.%s" % (iface.name, self.name))
 
         for hook in self.prehooks:
             request = hook(iface, self, request)
 
-        args = tuple(_fetch_argument(request.args, name)
+        args = tuple(_fetch_argument(request.args, name, iface.name, self.name)
             for name in self.required_arguments)
         kwargs = dict((name, request.args[name])
             for name in self.optional_arguments
@@ -266,9 +272,10 @@ class Method(object):
 # Private
 
 
-def _fetch_argument(args, name):
+def _fetch_argument(args, name, method_name, iface_name):
     """Fetch given argument from args."""
     try:
         return args[name]
     except KeyError:
-        raise exceptions.BadRequest("Argument '%s' is required" % name)
+        raise exceptions.BadRequest("Argument '%s' is required for %s.%s" %
+            (name, method_name, iface_name))
