@@ -31,13 +31,11 @@ import os
 import uuid
 from optparse import OptionParser
 
-from six import iterkeys
-
 from . import base, constants, exceptions, interfaces, nsclient
 from . import utils, zerojson
 
 
-def main(argv=None):
+def main(argv=None, client_context=None):
     """Starts main loop for a service.
 
     Raises :exc:`pycom.ConfigurationError` if not configured properly -
@@ -52,7 +50,11 @@ def main(argv=None):
 
     Returns 0MQ IOLoop exit code.
 
+    *client_context* can be used to override context, which is used
+    to register services.
+
     """
+    client_context = client_context or nsclient.Context()
     address = base.configuration.get("address")
     service = base.configuration.get("service")
 
@@ -96,19 +98,27 @@ def main(argv=None):
     if service is None:
         service = "/auto/" + uuid.uuid4().hex
 
-    ns_component = nsclient.nameserver()
-    for interface in iterkeys(interfaces.registry):
-        ns_component.invoke(constants.NS_METHOD_REGISTER, args={
+    def _register():  # pylint: disable-msg=C0111
+        client_context.nameserver().invoke(constants.NS_METHOD_REGISTER, args={
             "address": address,
-            "interface": interface,
+            "interfaces": list(interfaces.registry.keys()),
             "service": service
         })
 
+    _register()
+
     zerojson.setup_ioloop(address)
 
     utils.logger().info("PyCOM v%s (service '%s' on '%s')",
         constants.__version__, service, address)
+
+    callback = zerojson.create_task(_register,
+        constants.NS_SERVICE_TIMEOUT // 2)
+    callback.start()
+
     try:
         return zerojson.ioloop().start()
     except KeyboardInterrupt:  # pragma: no cover
         utils.logger().info("Got KeyboardInterrupt, exiting")
+    finally:
+        callback.stop()
