@@ -26,50 +26,56 @@
 
 """Synchronous client API for PyCOM nameserver."""
 
+import warnings
+
 from . import base, constants, exceptions, interfaces, zerojson
 
 
-def nameserver():
+def nameserver():   # pragma: no cover
     """Get nameserver component with default context.
 
-    This function uses global context, thus is not thread-safe.
-    See :meth:`pycom.Context.nameserver`.
+    Deprecated, do not use.
 
     """
+    warnings.warn("pycom.nameserver() is deprecated, use pycom.Context",
+        stacklevel=2)
     return _default_context.nameserver()
 
 
-def locate(*args, **kw):
+def locate(*args, **kw):   # pragma: no cover
     """Locate a service with default context.
 
-    This function uses global context, thus is not thread-safe.
-    See :meth:`pycom.Context.locate`.
+    Deprecated, do not use.
 
     """
+    warnings.warn("pycom.locate() is deprecated, use pycom.Context",
+        stacklevel=2)
     return _default_context.locate(*args, **kw)
 
 
 class Context(object):
     """Context is a main high-level class for accessing components.
 
-    .. attribute:: extensions
-
-       Dictionary with extensions data that should be
-       passed with every request.
+    If *nameserver* is not present, uses global configuration.
 
     """
 
-    def __init__(self):
+    def __init__(self, nameserver=None):
         """Constructor."""
-        self.extensions = {}
         self._ns_component = None
+        self._ns_hint = nameserver
 
     def nameserver(self):
         """Get nameserver component."""
         if self._ns_component is not None:
             return self._ns_component
 
-        ns_conf = base.configuration.get("nameserver", constants.NS_NAME_LOCAL)
+        if self._ns_hint is not None:
+            ns_conf = self._ns_hint
+        else:
+            ns_conf = base.configuration.get("nameserver",
+                constants.NS_NAME_LOCAL)
+
         if ns_conf == constants.NS_NAME_LOCAL:
             try:
                 ns_instance = interfaces.registry[constants.IFACE_NAMESERVER]
@@ -103,15 +109,18 @@ class Context(object):
             else:
                 raise
 
-        return zerojson.RemoteComponent(info["address"], iface)
+        return self.connect(info["address"], iface)
 
+    def connect(self, address, iface):
+        """Connect to a service providing *iface* on a given *address*."""
+        return zerojson.RemoteComponent(address, iface, context=self)
 
 # Private
 
-_default_context = Context()
+_default_context = Context()    # Deprecated
 
 
-# Following functions exists only for tests!
+# Following functions exist only for tests!
 
 def _pop_cached_ns(ctx=_default_context):
     """Drop cached nameserver and return it."""
