@@ -270,9 +270,13 @@ class ArgumentsTest(BaseTest, unittest.TestCase):
         component = SimpleInterface.__interface__
         self.assertEqual(component.invoke(meth, {"arg1": 1, "arg2": 2}),
             [1, 2])
-        self.assertRaises(exceptions.BadRequest, component.invoke, meth,
+        self.assertRaisesRegexp(exceptions.BadRequest,
+            "test.test_interfaces.ArgumentsTest.testRequiredOnly.method1",
+            component.invoke, meth,
             {"arg2": 2})
-        self.assertRaises(exceptions.BadRequest, component.invoke, meth,
+        self.assertRaisesRegexp(exceptions.BadRequest,
+            "test.test_interfaces.ArgumentsTest.testRequiredOnly.method1",
+            component.invoke, meth,
             42)
 
     def testOptionalOnly(self):
@@ -291,8 +295,12 @@ class ArgumentsTest(BaseTest, unittest.TestCase):
             [1, 2])
         self.assertEqual(component.invoke(meth, {"arg2": 2}),
             [100500, 2])
-        self.assertRaises(exceptions.BadRequest, component.invoke, meth,
+        self.assertRaisesRegexp(exceptions.BadRequest,
+            "test.test_interfaces.ArgumentsTest.testOptionalOnly.method1",
+            component.invoke, meth,
             42)
+        self.assertEqual(component.invoke(meth),
+            [100500, 100501])
 
     def testResults(self):
         iface = "test.test_interfaces.ArgumentsTest.testResults"
@@ -369,9 +377,13 @@ class ArgumentsTest(BaseTest, unittest.TestCase):
             [0, 1, 2])
         self.assertEqual(component.invoke(meth, {"arg0": 0}),
             [0, 100500, 42])
-        self.assertRaises(exceptions.BadRequest, component.invoke, meth,
+        self.assertRaisesRegexp(exceptions.BadRequest,
+            "test.test_interfaces.ArgumentsTest.testAllArguments.method1",
+            component.invoke, meth,
             {"arg2": 2})
-        self.assertRaises(exceptions.BadRequest, component.invoke, meth,
+        self.assertRaisesRegexp(exceptions.BadRequest,
+            "test.test_interfaces.ArgumentsTest.testAllArguments.method1",
+            component.invoke, meth,
             42)
 
 
