@@ -40,6 +40,8 @@ from .test_interfaces import BaseTest as InterfacesBaseTest
 
 class BaseTest(InterfacesBaseTest):
 
+    timeout = 3
+
     def setUp(self):
         super(BaseTest, self).setUp()
         self.oldNS = nsclient._pop_cached_ns()
@@ -52,7 +54,8 @@ class BaseTest(InterfacesBaseTest):
 class LocalNSTest(BaseTest, unittest.TestCase):
 
     def testErrorOnAbsentNameserver(self):
-        self.assertRaises(exceptions.ServiceNotFound, pycom.nameserver)
+        self.assertRaises(exceptions.ServiceNotFound,
+            pycom.Context().nameserver)
 
     def testErrorOnMalformedNS(self):
         pycom.configure(nameserver="host:unknown.unknown")
@@ -60,13 +63,14 @@ class LocalNSTest(BaseTest, unittest.TestCase):
         @pycom.interface(constants.IFACE_NAMESERVER)
         class Nameserver(object): pass
 
-        self.assertRaises(exceptions.ConfigurationError, pycom.nameserver)
+        self.assertRaises(exceptions.ConfigurationError,
+            pycom.Context().nameserver)
 
     def testNsInThisService(self):
         @pycom.interface(constants.IFACE_NAMESERVER)
         class Nameserver(object): pass
 
-        ns = pycom.nameserver()
+        ns = pycom.Context().nameserver()
         self.assertIsInstance(ns, pycom.BaseComponent)
         self.assertIsInstance(ns.instance, Nameserver)
 
@@ -74,11 +78,13 @@ class LocalNSTest(BaseTest, unittest.TestCase):
         @pycom.interface(constants.IFACE_NAMESERVER)
         class Nameserver(object): pass
 
-        ns1 = pycom.nameserver()
-        self.assertIs(ns1, pycom.nameserver())
+        context = pycom.Context()
+
+        ns1 = context.nameserver()
+        self.assertIs(ns1, context.nameserver())
 
         interfaces.registry.clear()
-        self.assertIs(ns1, pycom.nameserver())
+        self.assertIs(ns1, context.nameserver())
 
 
 def fake_container(context, event, addr, event2, handler):
@@ -140,26 +146,74 @@ class RemoteNSTest(BaseTest, unittest.TestCase):
         super(RemoteNSTest, self).tearDown()
 
     def testNS(self):
-        ns = pycom.nameserver()
+        ns = pycom.Context().nameserver()
         self.assertDictEqual(ns.invoke(constants.NS_METHOD_STAT), {})
         self.assertRaises(exceptions.RemoteError,
             ns.invoke, constants.NS_METHOD_LOCATE, {
                 "interface": "org.pycom.test_nsclient.NON-EXISTING"
             })
 
+    def testNSContextManager(self):
+        with pycom.Context().nameserver() as ns:
+            self.assertDictEqual(ns.invoke(constants.NS_METHOD_STAT), {})
+            self.assertRaises(exceptions.RemoteError,
+                ns.invoke, constants.NS_METHOD_LOCATE, {
+                    "interface": "org.pycom.test_nsclient.NON-EXISTING"
+                })
+
     def testUnknownNS(self):
-        pycom.configure(nameserver="ipc://pycom/banana!")
+        context = pycom.Context(nameserver="ipc://pycom/banana!")
         with Replacer(constants, "PROTO_DEFAULT_TIMEOUT", 100):
-            self.assertRaises(exceptions.ServiceNotFound, pycom.nameserver)
+            self.assertRaises(exceptions.ServiceNotFound, context.nameserver)
 
     def testUnknownNS2(self):
-        pycom.configure(nameserver="inproc://pycom/banana!")
+        context = pycom.Context(nameserver="inproc://pycom/banana!")
         with Replacer(constants, "PROTO_DEFAULT_TIMEOUT", 100):
-            self.assertRaises(exceptions.ServiceNotFound, pycom.nameserver)
+            self.assertRaises(exceptions.ServiceNotFound, context.nameserver)
 
     def testLocateError(self):
         self.assertRaises(exceptions.ServiceNotFound,
-            pycom.locate, "org.pycom.test_nsclient.NON-EXISTING")
+            pycom.Context().locate, "org.pycom.test_nsclient.NON-EXISTING")
+
+
+class RemoteNSTestContext(BaseTest, unittest.TestCase):
+
+    def setUp(self):
+        super(RemoteNSTestContext, self).setUp()
+
+        self.addr = "inproc://test_nsclient_ns-%d" % random.randint(0, 100000)
+
+        self.event = threading.Event()
+        event2 = threading.Event()
+
+        self.thread = threading.Thread(target=fake_container,
+            args=(common.context, self.event, self.addr, event2,
+            ns_handler))
+        self.thread.start()
+        event2.wait()
+
+    def tearDown(self):
+        self.event.set()
+        del self.event
+        self.thread.join()
+        del self.thread
+        self.context = None
+
+        super(RemoteNSTestContext, self).tearDown()
+
+    def testNS(self):
+        self.context = pycom.Context(nameserver=self.addr)
+        ns = self.context.nameserver()
+        self.assertDictEqual(ns.invoke(constants.NS_METHOD_STAT), {})
+        self.assertRaises(exceptions.RemoteError,
+            ns.invoke, constants.NS_METHOD_LOCATE, {
+                "interface": "org.pycom.test_nsclient.NON-EXISTING"
+            })
+
+    def testLocate(self):
+        self.context = pycom.Context(nameserver=self.addr)
+        self.assertRaises(exceptions.ServiceNotFound,
+            self.context.locate, "org.pycom.test_nsclient.NON-EXISTING")
 
 
 def ns_handler_w_error(request):
@@ -200,7 +254,7 @@ class LocateFailureTest(BaseTest, unittest.TestCase):
 
     def testUnknownError(self):
         with self.assertRaises(exceptions.RemoteError) as cm:
-            pycom.locate("org.pycom.test_nsclient.NON-EXISTING")
+            pycom.Context().locate("org.pycom.test_nsclient.NON-EXISTING")
         self.assertEqual(cm.exception.code, 100500)
 
 
@@ -228,14 +282,14 @@ class LocateTest(BaseTest, unittest.TestCase):
     def setUp(self):
         super(LocateTest, self).setUp()
 
-        addr = "inproc://test_nsclient_ns-%d" % random.randint(0, 100000)
-        pycom.configure(nameserver=addr)
+        self.addr = "inproc://test_nsclient_ns-%d" % random.randint(0, 100000)
+        pycom.configure(nameserver=self.addr)
 
         self.event = threading.Event()
         event2 = threading.Event()
 
         self.thread = threading.Thread(target=fake_container,
-            args=(common.context, self.event, addr, event2,
+            args=(common.context, self.event, self.addr, event2,
             ns_handler2))
         self.thread.start()
         event2.wait()
@@ -248,18 +302,34 @@ class LocateTest(BaseTest, unittest.TestCase):
 
         super(LocateTest, self).tearDown()
 
+    def testConnect(self):
+        ctx = pycom.Context()
+        component = ctx.connect(self.addr, constants.IFACE_NAMESERVER)
+        self.assertIsInstance(component, pycom.BaseComponent)
+        self.assertEqual(component.invoke(constants.NS_METHOD_STAT), {})
+        self.assertIs(component.context, ctx)
+
     def testLocate(self):
-        component = pycom.locate("iface.name")
+        ctx = pycom.Context()
+        component = ctx.locate("iface.name")
         self.assertIsInstance(component, pycom.BaseComponent)
         self.assertEqual(component.iface, "iface.name")
         self.assertIsInstance(component.socket, zmq.Socket)
+        self.assertIs(component.context, ctx)
+
+    def testLocateContextManager(self):
+        with pycom.Context().locate("iface.name") as component:
+            self.assertIsInstance(component, pycom.BaseComponent)
+            self.assertEqual(component.iface, "iface.name")
+            self.assertIsInstance(component.socket, zmq.Socket)
 
     def testLocateWService(self):
-        component = pycom.locate("iface.name2", service_name="service.name2")
+        component = pycom.Context().locate("iface.name2",
+            service_name="service.name2")
         self.assertIsInstance(component, pycom.BaseComponent)
         self.assertEqual(component.iface, "iface.name2")
         self.assertIsInstance(component.socket, zmq.Socket)
 
     def testLocateFail(self):
         self.assertRaises(exceptions.ServiceNotFound,
-            pycom.locate, "org.pycom.test_nsclient.NON-EXISTING")
+            pycom.Context().locate, "org.pycom.test_nsclient.NON-EXISTING")
