@@ -24,7 +24,7 @@
 #   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 #   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-"""Tests for pycom.utils."""
+"""Tests for pycom.utils and pycom.base."""
 
 import os
 import sys
@@ -64,6 +64,12 @@ class TestUUIDFactory(unittest.TestCase):
 
         self.assertDictEqual(factory.get(sessid), {"item": 42})
 
+        factory.get(sessid).discard()
+        self.assertRaises(KeyError, factory.get, sessid)
+
     def testNonExisting(self):
         factory = utils.UUIDFactory(base.Session)
         self.assertRaises(KeyError, factory.get, "banana!")
+
+    def testDiscardWoOwner(self):
+        base.Session(None).discard()
