@@ -65,8 +65,9 @@ class UUIDFactory(object):
     def new(self):
         """Create new session object and return it."""
         unique_id = uuid.uuid1().hex
-        self._items[unique_id] = self._items_factory(unique_id)
-        return self._items[unique_id]
+        self._items[unique_id] = self._items_factory(unique_id,
+            session_factory=self)
+        return self.get(unique_id)  # Allow for overloading
 
     def get(self, unique_id):
         """Fetch existing item by it's ID.
@@ -76,6 +77,10 @@ class UUIDFactory(object):
         """
         return self._items[unique_id]
 
+    def drop(self, unique_id):
+        """Drop existing item by it's ID."""
+        del self._items[unique_id]
+
 
 # Initialize logger
 
@@ -84,4 +89,6 @@ _logging_formatter = logging.Formatter(
     fmt="PyCOM %(levelname)s %(asctime)s: %(message)s")
 _logging_handler = logging.StreamHandler()
 _logging_handler.setFormatter(_logging_formatter)
+
 logger().addHandler(_logging_handler)
+logger().propagate = False
