@@ -26,12 +26,16 @@
 
 """Package with JSON-over-ZeroMQ."""
 
+from .eventloop import (
+    create_task,
+    ioloop,
+    )
+
 from .client import (
     RemoteComponent,
     detect_ns
     )
 
 from .server import (
-    ioloop,
     setup_ioloop
     )
