@@ -28,61 +28,21 @@
 
 from .. import base, constants, exceptions, interfaces, utils
 
-from . import common
+from . import prepare, run
 
 
-class CallCommand(common.BaseCommand):
+class CallCommand(prepare.PrepareCommand, run.RunCommand):
     """CALL command implementation.
 
-    Inherits :class:`pycom.zerojson.common.BaseCommand`.
+    Inherits :class:`pycom.zerojson.prepare.PrepareCommand`
+    and :class:`pycom.zerojson.prepare.RunCommand`.
 
     """
 
-    def __init__(self):
-        """Constructor."""
-        super(CallCommand, self).__init__()
-
-    # pylint: disable-msg=W0221
-
-    def request_to_dict(self, iface_name, method_name, args, session_id=None):
-        """Dump request to Python dict."""
-        return {
-            "interface": iface_name,
-            "method": method_name,
-            "session_id": session_id,
-            "args": args
-        }
-
-    def response_to_dict(self, response):
-        """Dump response to Python dict."""
-        result = {
-            "session_id": response.session_id
-        }
-
-        if not response.code:
-            result["result"] = response.result
-
-        return result
-
-    def request_from_dict(self, data):
-        """Get request from Python dict."""
-        try:
-            session = self.session_factory.get(data["session_id"])
-        except KeyError:
-            session = self.session_factory.new()
-            utils.logger().debug("NEW SESSION '%s'", session.session_id)
-
-        try:
-            return base.Request(data["interface"], data["method"], session,
-                data.get("args", None))
-        except KeyError as err:
-            raise exceptions.BadRequest("Field %s is required" % err.args[0])
-
-    def response_from_dict(self, data):
-        """Get request from Python dict."""
-        return data.get("result", None), data.get("session_id", None)
-
-    # pylint: enable-msg=W0221
+    request_to_dict = prepare.PrepareCommand.request_to_dict
+    request_from_dict = prepare.PrepareCommand.request_from_dict
+    response_to_dict = run.RunCommand.response_to_dict
+    response_from_dict = run.RunCommand.response_from_dict
 
     def real_process_request(self, request, *other_parts):
         """Call to process request."""
