@@ -30,7 +30,9 @@ import json
 
 import zmq
 
-from .. import base, constants, exceptions, utils
+from . import eventloop
+
+from .. import base, constants, exceptions
 
 
 class BaseCommand(object):
@@ -49,7 +51,9 @@ class BaseCommand(object):
 
     """
 
-    session_factory = utils.UUIDFactory(base.Session)  #: Session factory
+    session_factory = eventloop.ExpiringFactory(base.Session,
+        timeout=constants.PROTO_SESSION_TIMEOUT,
+        message="Session '%s' expired")  #: Session factory
 
     # call_factory = utils.UUIDFactory(Call)  #: Shared factory for call info
 
