@@ -27,29 +27,18 @@
 """Server code for JSON-over-ZeroMQ."""
 
 import zmq
-from zmq import eventloop
 
 from .. import base, constants, utils
 
-from . import call, common
-
-
-def ioloop():
-    """Returns 0MQ *IOLoop* instance for current event loop.
-
-    Roughly equivalent to::
-
-        zmq.eventloop.IOLoop.instance()
-
-    """
-    return eventloop.IOLoop.instance()
+from . import call, common, eventloop
 
 
 def setup_ioloop(address):
     """Setup io loop for working as a server on given *address*."""
     sock = common.context.socket(zmq.REP)
     sock.bind(address)
-    ioloop().add_handler(sock, _message_handler, ioloop().READ)
+    eventloop.ioloop().add_handler(sock, _message_handler,
+        eventloop.ioloop().READ)
 
 
 # Private
