@@ -30,6 +30,7 @@
 from __future__ import print_function
 
 import logging
+import os
 
 if __name__ == '__main__':
     try:
@@ -53,6 +54,9 @@ if __name__ == '__main__':
     utils.logger().addHandler(new_handler)
     utils.logger().setLevel(logging.DEBUG)
 
+    # Prevent pycom.main() from overwriting logging level
+    os.environ["PYCOM_LOGGING_LEVEL"] = str(logging.DEBUG)
+
     from pycom.test.utils import unittest
 
     tests = unittest.defaultTestLoader.discover(".")
